## Static files

Sources:

`gallery-*.png` and `favicon.ico`: See ../../../icon/README.md in the project.

Bootstrap:

* https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/css/bootstrap.min.css
* https://cdn.jsdelivr.net/npm/bootstrap@5.3.3/dist/js/bootstrap.bundle.min.js
